@@ -33,7 +33,6 @@
 #include <matekbd-keyboard-drawing-marshal.h>
 #include <matekbd-util.h>
 
-#define noKBDRAW_DEBUG
 
 #define INVALID_KEYCODE ((guint)(-1))
 
@@ -2156,7 +2155,6 @@ xkb_state_notify_event_filter (GdkXEvent * gdkxev,
 			       GdkEvent * event,
 			       MatekbdKeyboardDrawing * drawing)
 {
-#define group_change_mask (XkbGroupStateMask | XkbGroupBaseMask | XkbGroupLatchMask | XkbGroupLockMask)
 #define modifier_change_mask (XkbModifierStateMask | XkbModifierBaseMask | XkbModifierLatchMask | XkbModifierLockMask)
 
 	if (!drawing->xkb)
