@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -49,6 +49,11 @@ main (int argc, char **argv)
 
 	icon = matekbd_status_new ();
 
+        if (icon == NULL)
+	{
+		return 1;
+	}
+
 	gtk_main ();
 
 	return 0;
